@@ -14,7 +14,7 @@ use Digest::SHA qw(hmac_sha256 hmac_sha256_hex);
 use MIME::Base64::URLSafe qw(urlsafe_b64decode);
 use Scalar::Util qw(blessed);
 
-our $VERSION = '1.30';
+our $VERSION = '1.31';
 
 sub new {
     my $class = shift;
@@ -451,8 +451,11 @@ sub request {
 
     my $content = q{};
     if ($method eq 'POST') {
-        if ($param_ref->{source} || $param_ref->{file} || $param_ref->{upload_phase} ) {
-            # post image or video file
+        if ($param_ref->{source}
+            || $param_ref->{file}
+            || $param_ref->{upload_phase}
+            || $param_ref->{captions_file}) {
+            # post image, video or caption file
 
             # https://developers.facebook.com/docs/reference/api/video/
             # When posting a video, use graph-video.facebook.com .
@@ -576,16 +579,11 @@ sub prep_param {
         $param_ref->{permissions} = ref $perms ? join q{,}, @$perms : $perms;
     }
 
-    # Source, file and video_file_chunk parameter contains file path.
+    # Source, file, video_file_chunk and captions_file parameter contains file path.
     # It must be an array ref to work with HTTP::Request::Common.
-    if (my $path = $param_ref->{source}) {
-        $param_ref->{source} = ref $path ? $path : [$path];
-    }
-    if (my $path = $param_ref->{file}) {
-        $param_ref->{file} = ref $path ? $path : [$path];
-    }
-    if (my $path = $param_ref->{video_file_chunk}) {
-        $param_ref->{video_file_chunk} = ref $path ? $path : [$path];
+    for my $file (qw/source file video_file_chunk captions_file/) {
+        next unless my $path = $param_ref->{$file};
+        $param_ref->{$file} = ref $path ? $path : [$path];
     }
 
     # use Field Expansion
@@ -686,7 +684,7 @@ Facebook::OpenGraph - Simple way to handle Facebook's Graph API.
 
 =head1 VERSION
 
-This is Facebook::OpenGraph version 1.30
+This is Facebook::OpenGraph version 1.31
 
 =head1 SYNOPSIS
 
@@ -1175,7 +1173,7 @@ Request batch request and returns an array reference.
 =head3 C<< $fb->batch(\@requests) >>
 
 Request batch request and returns an array reference of response objects. It
-sets C<$fb->access_token> as top level access token, but other than that you
+sets C<< $fb->access_token >> as top level access token, but other than that you
 can specify indivisual access token for each request. The document says
 "The Batch API is flexible and allows individual requests to specify their own
 access tokens as a query string or form post parameter. In that case the top
